@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: DAV
 version: 1.2
-id: DAV-1.2-030d1c7850b5196989a74deb7c540106
-key: DAV_Fnes6JcQvZ2BN5niJygl4u
+id: DAV-1.2-ae024cb51706f5e54023437899011d4c
+key: DAV_0tAiBOmPopcE31pppNUdhw
 license: GPL-3
 copyright: Copyright (C) 2012-2015  Clint Adams
 maintainer: clint@debian.org
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/DAV-1.2
-hs-libraries: HSDAV-1.2-Fnes6JcQvZ2BN5niJygl4u
+hs-libraries: HSDAV-1.2-0tAiBOmPopcE31pppNUdhw
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -34,17 +34,17 @@ depends:
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
-    http-client-tls-0.2.2-05f6aae0a8612df864dc61b6b7405a00
+    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
+    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
     http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lens-4.13.2.1-3b086cb541bae44e8089b135a290af93
+    lens-4.13.2.1-51cb0aae339c8977636563c0e1cbdfa1
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
-    xml-conduit-1.3.4-2cb0835929c2dc7743cd241414dfd06a
-    xml-hamlet-0.4.0.11-566246a1988e00b045f326b729e7bb45
+    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
+    xml-hamlet-0.4.0.11-0c1bb389bc2a3ce0045aa2368d4cab75
 haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
 haddock-html: /usr/share/doc/haskell-dav/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
